summaryrefslogtreecommitdiffstats
path: root/generic/tkTextIndex.c
diff options
context:
space:
mode:
authordgp@users.sourceforge.net <dgp>2012-12-04 17:02:22 (GMT)
committerdgp@users.sourceforge.net <dgp>2012-12-04 17:02:22 (GMT)
commit34da371029fe28e14970060dc22ee62907d3863f (patch)
treecd8002bc80338c375b21e3ec5c47e7c1aee382c3 /generic/tkTextIndex.c
parentb5ca6dd0d1a46be5b85a6941ab8e65b0b3870d9e (diff)
parent2b6a82bc09290a8286de412413d3c9cf9b3380d3 (diff)
downloadtk-34da371029fe28e14970060dc22ee62907d3863f.zip
tk-34da371029fe28e14970060dc22ee62907d3863f.tar.gz
tk-34da371029fe28e14970060dc22ee62907d3863f.tar.bz2
[Bug 3588824]: bug in image index handling for weird image names
Diffstat (limited to 'generic/tkTextIndex.c')
-rw-r--r--generic/tkTextIndex.c16
1 files changed, 13 insertions, 3 deletions
diff --git a/generic/tkTextIndex.c b/generic/tkTextIndex.c
index 25888d8..fc97412 100644
--- a/generic/tkTextIndex.c
+++ b/generic/tkTextIndex.c
@@ -760,9 +760,11 @@ GetIndex(
/*
*---------------------------------------------------------------------
* Stage 1: check to see if the index consists of nothing but a mark name.
* We do this check now even though it's also done later, in order to
* allow mark names that include funny characters such as spaces or "+1c".
*---------------------------------------------------------------------
*/
@@ -770,6 +772,14 @@ GetIndex(
goto done;
}
+ if (TkTextWindowIndex(textPtr, string, indexPtr) != 0) {
+ return TCL_OK;
+ }
+
+ if (TkTextImageIndex(textPtr, string, indexPtr) != 0) {
+ return TCL_OK;
+ }
+
/*
*------------------------------------------------
* Stage 2: start again by parsing the base index.
@@ -760,9 +760,11 @@ GetIndex(
/*
*---------------------------------------------------------------------
- * Stage 1: check to see if the index consists of nothing but a mark name.
- * We do this check now even though it's also done later, in order to
- * allow mark names that include funny characters such as spaces or "+1c".
+ * Stage 1: check to see if the index consists of nothing but a mark
+ * name, an embedded window or an embedded image. We do this check
+ * now even though it's also done later, in order to allow mark names,
+ * embedded window names or image names that include funny characters
+ * such as spaces or "+1c".
*---------------------------------------------------------------------
*/